
 
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <gdk/gdk.h>
#include <webkit/webkit.h>
#include <string.h>
#include <gconf/gconf.h>
#include <gconf/gconf-client.h>

#include "interface.h"
#include "support.h"
#include "main.h"

GtkWidget *window1;
GtkWidget *web_view = NULL;
GtkWidget *bookmark_view = NULL;
GtkTreeModel *bookmark_model;
GList *bookmark_list = NULL;

GtkAdjustment *web_view_hadjustment;
GtkAdjustment *web_view_vadjustment;
WebKitWebSettings *settings = NULL;

GConfClient *gconfclient = NULL;

const char *current_url = NULL;
const char *current_title = NULL;
int web_view_height;
int web_view_width;

gboolean pref_image_load = TRUE;
gboolean pref_javascript = TRUE;
gchar *pref_homepage = NULL;

void
preferences_save();

enum
{
  COL_NAME = 0,
  COL_LOCATION,
  NUM_COLS
} ;

void
prefs_load()
{
	gboolean loadimages, javascript;
	int fontsize;
	char *homepage;
	GtkWidget *widget;
	
	if(!gconfclient)
		gconfclient = gconf_client_get_default();
	
	loadimages = gconf_client_get_bool(gconfclient, "/apps/woosh/image_load", NULL);
	widget = lookup_widget(window1, "checkbutton2");
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),loadimages);
	
	javascript = gconf_client_get_bool(gconfclient, "/apps/woosh/javascript", NULL);
	widget = lookup_widget(window1, "checkbutton1");
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),javascript);
		
	
}

void
preferences_toggle_show(int toggle)
{
	static gboolean show = FALSE;
	
	GtkWidget *scrolled_window = lookup_widget(window1, "scrolledwindow2");
	GtkWidget *scrolled_window_web_view = lookup_widget(window1, "scrolledwindow1");
	GtkWidget *widget;
	
	printf("** %s \n", __func__);

	widget = lookup_widget(window1,"hbox4");
		
	
	if((!show && toggle == 0)|| toggle == 1) 
	{
		toggle_bookmark_view(-1);

		gtk_widget_hide(scrolled_window_web_view);
		gtk_widget_hide(scrolled_window);
		show_location_bar(FALSE);
		gtk_widget_show(widget);
		show = TRUE;
	}
	else if ((show && toggle == 0) || toggle == -1)
	{
		gtk_widget_hide(widget);
		gtk_widget_show(scrolled_window_web_view);
		//preferences_save();
		show = FALSE;
	}
}



void
preferences_save()
{
	static gboolean full = TRUE;
	

	//settings = webkit_web_settings_new ();
	settings = webkit_web_view_get_settings(WEBKIT_WEB_VIEW(web_view));
	
        g_object_set (
                settings,
                "default-font-size",
                11,
                NULL
        );
        g_object_set (
                settings,
                "minimum-font-size",
                7,
                NULL
        );

        g_object_set (
                settings,
                "enable-plugins",
                FALSE,
                NULL
        );

	if(full)
	{
		g_object_set (
			settings,
			"auto-load-images",
			FALSE,
			NULL
		);
		        g_object_set (
                settings,
                "enable-scripts",
                FALSE,
                NULL
        );
		full = FALSE;
		printf("no more auto load images\n");
	}
	else
	{
		g_object_set (
			settings,
			"auto-load-images",
			TRUE,
			NULL
		);
		        g_object_set (
                settings,
                "enable-scripts",
                TRUE,
                NULL
        );
		full = TRUE;		printf("NOW auto load images\n");

	}
        webkit_web_view_set_settings (WEBKIT_WEB_VIEW(web_view), WEBKIT_WEB_SETTINGS (settings));	
	
}

void
prefs_javascript_toggle(gboolean active)
{
	printf("** %s %d\n", __func__, active);

	settings = webkit_web_view_get_settings(WEBKIT_WEB_VIEW(web_view));
 	g_object_set (	settings,
			"enable-scripts",
			active,
			NULL);
	if(!gconfclient)
		gconfclient = gconf_client_get_default();
	gconf_client_set_bool(gconfclient, "/apps/woosh/javascript", active, NULL);
        webkit_web_view_set_settings (WEBKIT_WEB_VIEW(web_view), WEBKIT_WEB_SETTINGS (settings));
}

void
prefs_image_load_toggle(gboolean active)
{
	printf("** %s %d\n", __func__, active);

	settings = webkit_web_view_get_settings(WEBKIT_WEB_VIEW(web_view));
	//pref_image_load = (pref_image_load) ? FALSE : TRUE;
 	g_object_set (	settings,
			"auto-load-images",
			active,
			NULL);
	if(!gconfclient)
		gconfclient = gconf_client_get_default();
	gconf_client_set_bool(gconfclient, "/apps/woosh/image_load", active, NULL);
        webkit_web_view_set_settings (WEBKIT_WEB_VIEW(web_view), WEBKIT_WEB_SETTINGS (settings));	
}

void
prefs_set_homepage(char *homepage)
{
	printf("** %s \n", __func__);
	if(!gconfclient)
		gconfclient = gconf_client_get_default();
	gconf_client_set_string(gconfclient, "/apps/woosh/homepage", homepage, NULL);
}

void
prefs_set_default_font_size(int fontsize)
{
	printf("** %s size: %d\n", __func__, fontsize);

	settings = webkit_web_view_get_settings(WEBKIT_WEB_VIEW(web_view));
 	g_object_set (	settings,
			"default-font-size",
			fontsize,
			NULL);
	if(!gconfclient)
		gconfclient = gconf_client_get_default();
	gconf_client_set_int(gconfclient, "/apps/woosh/default_font_size", fontsize, NULL);
        webkit_web_view_set_settings (WEBKIT_WEB_VIEW(web_view), WEBKIT_WEB_SETTINGS (settings));
}

 gboolean
  bookmark_foreach_func (GtkTreeModel *model,
                GtkTreePath  *path,
                GtkTreeIter  *iter,
                gpointer      user_data)
  {
    gchar *name, *location, *tree_path_str;

    /* Note: here we use 'iter' and not '&iter', because we did not allocate
     *  the iter on the stack and are already getting the pointer to a tree iter */

    gtk_tree_model_get (model, iter,
                        COL_NAME, &name,
                        COL_LOCATION, &location,
                        -1);

    tree_path_str = gtk_tree_path_to_string(path);

    g_print ("Row %s: %s %s \n", tree_path_str,
             name, location);

	  bookmark_list = g_list_append(bookmark_list, g_strdup_printf("%s\x1F%s",name,location));
    g_free(tree_path_str);

    g_free(name); /* gtk_tree_model_get made copies of       */
    g_free(location);  /* the strings for us when retrieving them */

    return FALSE; /* do not stop walking the store, call us with next row */
  }

  
static gchar* autocorrect_url(const gchar* url)
{
	printf("** %s \n", __func__);
	if (	strncmp ("https://", url, 8) != 0 &&
		strncmp ("http://", url, 7)  != 0 && 
		strncmp ("file://", url, 7)  != 0 && 
		strncmp ("ftp://", url, 6)   != 0 &&
		strncmp ("about:", url, 6)   != 0 )
	{
		GString* string = g_string_new ("http://");
		g_string_append (string, url);
		return g_string_free (string, FALSE);
	}
	
	return g_strdup (url);
}

void
get_tree_iter()
{
	GtkTreeSelection *selection;
	GtkTreeModel     *model;
	GtkTreeIter       iter;
	
	/* This will only work in single or browse selection mode! */
	
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(bookmark_view));
	if (gtk_tree_selection_get_selected(selection, &model, &iter))
	{
		gchar *url0;
		gchar *url;
		
		gtk_tree_model_get (model, &iter, COL_LOCATION, &url0, -1);
		url = autocorrect_url(url0);
		g_print ("selected bookmark is: %s\n", url);
		toggle_bookmark_view(0);
		webkit_web_view_open (WEBKIT_WEB_VIEW (web_view), url);
		
		g_free(url0);
		g_free(url);
	}
	else
	{
		g_print ("no row selected.\n");
	}

}	

GtkWidget *
get_web_view()
{
	return web_view;
}

void
toggle_bookmark_view(int toggle)
{
	static gboolean visible = FALSE;
	GtkWidget *scrolled_window = lookup_widget(window1, "scrolledwindow2");
	GtkWidget *scrolled_window_web_view = lookup_widget(window1, "scrolledwindow1");
	GtkWidget *hbox4 = lookup_widget(window1, "hbox4");
	
	// create+show / hide view
	if(!bookmark_view)
	{
		GtkWidget *eventbox = lookup_widget(window1, "eventbox6");

		bookmark_view = create_bookmark_view();
		gtk_container_add(GTK_CONTAINER(eventbox), bookmark_view);
		gtk_widget_show_all(scrolled_window);
		bookmark_model = GTK_TREE_MODEL(create_and_fill_model());
		gtk_tree_view_set_model(GTK_TREE_VIEW(bookmark_view), GTK_TREE_MODEL(bookmark_model));

	}
	
	if((!visible && toggle == 0)|| toggle == 1)
	{	
		preferences_toggle_show(-1);
		gtk_widget_hide(scrolled_window_web_view);
		gtk_widget_hide(hbox4);
		gtk_widget_show(scrolled_window);
		show_location_bar(TRUE);
		visible = TRUE;
	}
	else if ((visible && toggle == 0) || toggle == -1)
	{
		gtk_widget_hide(scrolled_window);
		gtk_widget_show(scrolled_window_web_view);
		show_location_bar(FALSE);
		visible = FALSE;
	}
}


void
bookmark_save(GList *list)
{	
	gboolean res = TRUE;
	GError *err = NULL;
	
	if(!gconfclient)
		gconfclient = gconf_client_get_default();
	
	if(!gconfclient) printf("***NO GCONF\n");
	else printf("***GCONF OK\n");
	printf("** %s \n",__func__);

	// get gconf handle
	// save list to gconf
	if(!list) printf("no bookmarks\n");
	for(; list != NULL; list = list->next)
	{
		printf("bm: %s \n", (char *)list->data);
	}
        res = gconf_client_set_list(        gconfclient,
                                                "/apps/woosh/bookmarks",
                                                GCONF_VALUE_STRING,
                                                (GSList *)bookmark_list,
                                                &err);
	

	if(!res) printf("### bookmarks not saved\n");
	else printf("### bookmarks SAVED\n");
	if(err) printf("### bookmarks not saved due to ERROR\n");
		char *str = gconf_client_get_string(gconfclient, "/apps/woosh/bookmarksy",&err);
	printf("KEY: %s\n", str);
}

void
add_bookmark()
{
	GtkTreeIter    toplevel;
	printf("** %s %s %s\n",__func__, current_title, current_url);
	
	/* Append a top level row */
	gtk_tree_store_append(GTK_TREE_STORE(bookmark_model), &toplevel, NULL);
	gtk_tree_store_set(GTK_TREE_STORE(bookmark_model), &toplevel,
			   COL_NAME, current_title,
			   COL_LOCATION, current_url,
			   -1);
	
	bookmark_list = NULL;
	gtk_tree_model_foreach(bookmark_model, bookmark_foreach_func, NULL);
	bookmark_save(bookmark_list);
}

GtkTreeStore *
create_and_fill_model (void)
{
	GtkTreeStore  *treestore;
	GtkTreeIter    toplevel;
	GError *err = NULL;
	GList *list;
	
	treestore = gtk_tree_store_new(NUM_COLS,
				 G_TYPE_STRING,
				 G_TYPE_STRING);

	if(!gconfclient)
		gconfclient = gconf_client_get_default();
	
	
	bookmark_list = (GList *) gconf_client_get_list(gconfclient, "/apps/woosh/bookmarks", GCONF_VALUE_STRING, &err);
	
	if(err || !bookmark_list) printf("BOOKMARKS not loaded from GCONF\n");
	else printf("no error and bookmarks OK\n");
	
	for(list = bookmark_list; list != NULL; list = list->next)
	{
		int arr_len = 0;
		char **arr;
		arr = g_strsplit(list->data, "\x1F", -1);
		while (arr[arr_len]) arr_len++;

		
		if(arr_len >= 2)
		{
			printf("BOOKMARK: %s--%s | %s\n",(char *)list->data, arr[0], arr[1]);

			gtk_tree_store_append(treestore, &toplevel, NULL);
			gtk_tree_store_set(treestore, &toplevel,
			     COL_NAME, arr[0],
			     COL_LOCATION, arr[1],
			     -1);
		}
	}
if(!bookmark_list)
{	
  //**********************************************************
  //           DATA   DATA   DATA
  //**********************************************************
  
  /* Append a top level row and leave it empty */
  gtk_tree_store_append(treestore, &toplevel, NULL);
  gtk_tree_store_set(treestore, &toplevel,
                     COL_NAME, "BBC News",
                     COL_LOCATION, "http://news.bbc.co.uk/text_only.stm",
                     -1);
	
  /* Append a top level row and leave it empty */
  gtk_tree_store_append(treestore, &toplevel, NULL);
  gtk_tree_store_set(treestore, &toplevel,
                     COL_NAME, "Google",
                     COL_LOCATION, "http://www.google.com/",
                     -1);

  /* Append a second top level row, and fill it with some data */
  gtk_tree_store_append(treestore, &toplevel, NULL);
  gtk_tree_store_set(treestore, &toplevel,
                     COL_NAME, "Gmail",
                     COL_LOCATION, "http://mail.google.com/",
                     -1);

  /* Append a second top level row, and fill it with some data */
  gtk_tree_store_append(treestore, &toplevel, NULL);
  gtk_tree_store_set(treestore, &toplevel,
                     COL_NAME, "Maps",
                     COL_LOCATION, "http://maps.google.com/",
                     -1);
		     
  /* Append a second top level row, and fill it with some data */
  gtk_tree_store_append(treestore, &toplevel, NULL);
  gtk_tree_store_set(treestore, &toplevel,
                     COL_NAME, "Wikipedia",
                     COL_LOCATION, "http://en.wikipedia.org/",
                     -1);
		     
  /* Append a second top level row, and fill it with some data */
  gtk_tree_store_append(treestore, &toplevel, NULL);
  gtk_tree_store_set(treestore, &toplevel,
                     COL_NAME, "Linux FR",
                     COL_LOCATION, "http://linuxfr.org/",
                     -1);

  /* Append a second top level row, and fill it with some data */
  gtk_tree_store_append(treestore, &toplevel, NULL);
  gtk_tree_store_set(treestore, &toplevel,
                     COL_NAME, "Bearstech",
                     COL_LOCATION, "http://bearstech.com/",
                     -1);

  /* Append a child to the second top level row, and fill in some data */
/*  gtk_tree_store_append(treestore, &child, &toplevel);
  gtk_tree_store_set(treestore, &child,
                     COL_NAME, "Site",
                     COL_LOCATION, "URL",
                     -1);
*/
}
  return GTK_TREE_STORE(treestore);
}

GtkWidget *
create_bookmark_view (void)
{
	GtkTreeViewColumn   *col;
	GtkCellRenderer     *renderer;
	GtkWidget           *view;
	
	view = gtk_tree_view_new();
	
	/*********************/
	/***** Column #1 *****/
	/*********************/
	
	col = gtk_tree_view_column_new();
	gtk_tree_view_column_set_min_width(col, 50);
	gtk_tree_view_column_set_max_width(col, 250);
	gtk_tree_view_column_set_resizable(col, TRUE);
	gtk_tree_view_column_set_title(col, "Name");
	
	/* pack tree view column into tree view */
	gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
	
	renderer = gtk_cell_renderer_text_new();
	
	/* pack cell renderer into tree view column */
	gtk_tree_view_column_pack_start(col, renderer, TRUE);
	
	/* connect 'text' property of the cell renderer to
	*  model column that contains the first name */
	gtk_tree_view_column_add_attribute(col, renderer, "text", COL_NAME);
	
	/* set 'weight' property of the cell renderer to
	*  bold print (we want all last names in bold) */
	g_object_set(renderer,
	       "weight", PANGO_WEIGHT_BOLD,
	       "weight-set", TRUE,
	       NULL);
	       
	       
	/*********************/
	/***** Column #2 *****/
	/*********************/
	
	col = gtk_tree_view_column_new();
	
	gtk_tree_view_column_set_title(col, "Location");
	gtk_tree_view_column_set_resizable(col, TRUE);

	/* pack tree view column into tree view */
	gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
	
	renderer = gtk_cell_renderer_text_new();
	
	/* pack cell renderer into tree view column */
	gtk_tree_view_column_pack_start(col, renderer, TRUE);
	
	/* connect 'text' property of the cell renderer to
	*  model column that contains the last name */
	gtk_tree_view_column_add_attribute(col, renderer, "text", COL_LOCATION);
	

	
	
	
	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)),
			      GTK_SELECTION_SINGLE);
	
	return view;
}

void
win_resize()
{
	// superflous?
	if(web_view)
		web_view_height = web_view->allocation.height;
	//web_view_width  = web_view->allocation.width;
}

void
scroll_up()
{
	gdouble position;
	position = gtk_adjustment_get_value(web_view_vadjustment);
	gtk_adjustment_set_value(web_view_vadjustment, position - (0.9 * web_view->allocation.height));
}

void
scroll_down()
{
	gdouble position;
	position = gtk_adjustment_get_value(web_view_vadjustment);
	gtk_adjustment_set_value(web_view_vadjustment, position + (0.9 * web_view->allocation.height));
}

void
fullscreen()
{
	GtkWidget *widget = lookup_widget(window1, "eventbox2");
	GtkWidget *buttonbar = lookup_widget(window1, "hbox1");
	
	
	static gboolean is_max = FALSE;
	
	if(is_max) {
		gdk_window_unfullscreen(window1->window);
		gtk_widget_hide(widget);
		gtk_widget_show(buttonbar);
		is_max = FALSE;
	}	
	else {
		gdk_window_fullscreen(window1->window);
		show_location_bar(FALSE);
		gtk_widget_show(widget);
		gtk_widget_hide(buttonbar);
		is_max = TRUE;
	}
}

void
go_back()
{
	webkit_web_view_go_back(WEBKIT_WEB_VIEW(web_view));
}
void
go_forward()
{
	webkit_web_view_go_forward(WEBKIT_WEB_VIEW(web_view));
}

static gboolean
cb_link_clicked (WebKitWebView *view, WebKitWebFrame *frame, WebKitNetworkRequest *request)
{
	
	current_url = g_strdup(webkit_network_request_get_uri(request));
	printf("%s %s\n", __func__, current_url);
	gtk_widget_set_sensitive (lookup_widget(window1,"button3"), TRUE);
	gtk_entry_set_text(GTK_ENTRY(lookup_widget(window1, "entry1")),current_url);
	load_indicator(TRUE);
	
	return FALSE;	
}

static void cb_load_started (WebKitWebView  *web_view,
                             WebKitWebFrame *frame,
                             gpointer        user_data) 
{
	printf("* %s \n",__func__);
}
static void cb_load_committed (WebKitWebView  *web_view,
                             WebKitWebFrame *frame,
                             gpointer        user_data) 
{
	printf("* %s \n",__func__);
}
static void cb_load_finished (WebKitWebView  *web_view,
                             WebKitWebFrame *frame,
                             gpointer        user_data) 
{
	printf("* %s lower: %.0f  upper: %.0f\n", __func__, web_view_vadjustment->lower, web_view_vadjustment->upper);
	gtk_adjustment_set_value(web_view_vadjustment, 0.0);
}
static void 
cb_progress_changed(WebKitWebView* page, int prog, gpointer *data)
{
	printf("** %s %d\n", __func__, prog);
	//g_assert (page == data->currentPage->webKitPage);
	
	if (prog == 100) {
		gtk_widget_set_sensitive (lookup_widget(window1,"button1"), webkit_web_view_can_go_back (page));
		gtk_widget_set_sensitive (lookup_widget(window1,"button2"), webkit_web_view_can_go_forward (page));
		gtk_widget_set_sensitive (lookup_widget(window1,"button3"), FALSE);
		load_indicator(FALSE);
		//gtk_widget_set_sensitive (GTK_WIDGET (data->currentAdd), webkit_web_frame_get_title (webkit_web_view_get_main_frame (page)) != NULL);
		current_title = webkit_web_frame_get_title (webkit_web_view_get_main_frame (page));
		gdk_window_set_title(window1->window, current_title);
	}
}
void
go_to()
{
	GtkWidget *widget;
	const gchar *url0; 
	gchar *url;
	
	printf("** %s \n",__func__);
	
	// get text
	widget = lookup_widget(window1,"entry1");
	url0 = gtk_entry_get_text(GTK_ENTRY(widget));
	
	url = autocorrect_url(url0);
	webkit_web_view_open (WEBKIT_WEB_VIEW (web_view), url);
	toggle_bookmark_view(-1);
	g_free(url);
}

void
select_and_copy()
{
	gboolean can_copy;
	
	can_copy = webkit_web_view_can_copy_clipboard(WEBKIT_WEB_VIEW(web_view));
	if(can_copy) printf("copy\n");
	webkit_web_view_select_all(WEBKIT_WEB_VIEW(web_view));
	webkit_web_view_copy_clipboard(WEBKIT_WEB_VIEW(web_view));
}


void
load_indicator(gboolean loading)
{
	GdkColor color;
	static GtkWidget *widget = NULL;
printf("load\n");	
	if(!widget)
		widget = lookup_widget(window1, "eventbox2");

	if(loading)
	{
		color.red   = 65000;
		color.green = 30000;
		color.blue  = 30000;
	
		gtk_widget_modify_bg(widget, GTK_STATE_NORMAL, &color);
	}
	else
	{
		GdkColor color;
		color.red   = 65000;
		color.green = 65000;
		color.blue  = 65000;
	
		gtk_widget_modify_bg(widget, GTK_STATE_NORMAL, &color);
		
		color.red   = 50000;
		color.green = 50000;
		color.blue  = 5000;
		
		//does nothing currently
		gtk_widget_modify_bg(widget, GTK_STATE_PRELIGHT|GTK_STATE_ACTIVE, &color);
	}	
}

void
show_location_bar(gboolean show)
{
	GtkWidget *widget;
	
	widget = lookup_widget(window1, "hbox2");
	if(show)
	{
		gtk_widget_show(widget);
		gtk_widget_grab_focus(lookup_widget(window1, "entry1"));
	}
	else gtk_widget_hide(widget);
}
gboolean
create_web_view(gpointer *data)
{
	GtkWidget *scrolled_window, *widget;
	char *homepage;

	/* Create the widgets */
	scrolled_window = lookup_widget(window1, "scrolledwindow1");
	web_view = webkit_web_view_new ();
	
	/* Place the WebKitWebView in the GtkScrolledWindow */
	gtk_container_add (GTK_CONTAINER (scrolled_window), web_view);
	

	/* Show the result */
	//gtk_widget_show_all (window1);
	
	gtk_widget_show(web_view);
	widget = lookup_widget(window1, "label2");
	gtk_widget_hide(widget);
	
	
		g_signal_connect (
                web_view,
                "navigation-requested",
                G_CALLBACK (cb_link_clicked),
                web_view
    );

	g_signal_connect (
			web_view,
			"load-progress-changed",
			G_CALLBACK(cb_progress_changed), 
			web_view);

	g_signal_connect (
			web_view,
			"load-started",
			G_CALLBACK(cb_load_started), 
			web_view);
			
	g_signal_connect (
			web_view,
			"load-committed",
			G_CALLBACK(cb_load_committed), 
			web_view);
			
	g_signal_connect (
			web_view,
			"load-finished",
			G_CALLBACK(cb_load_finished), 
			web_view);
			

	settings = webkit_web_settings_new ();
        g_object_set (
                settings,
                "default-font-size",
                11,
                NULL
        );
        g_object_set (
                settings,
                "minimum-font-size",
                7,
                NULL
        );
        g_object_set (
                settings,
                "enable-scripts",
                TRUE,
                NULL
        );
        g_object_set (
                settings,
                "enable-plugins",
                FALSE,
                NULL
        );

        webkit_web_view_set_settings (WEBKIT_WEB_VIEW(web_view), WEBKIT_WEB_SETTINGS (settings));
	//webkit_web_view_set_editable(web_view, TRUE);
	prefs_load();
	
	/* Open a webpage */
	//webkit_web_view_open (WEBKIT_WEB_VIEW (web_view), "http://127.0.0.1/"); //"http://www.google.com/");
	if(!gconfclient)
		gconfclient = gconf_client_get_default();
	homepage = gconf_client_get_string(gconfclient, "/apps/woosh/homepage", NULL);
	widget = lookup_widget(window1, "entry2");
	if(homepage){
		gtk_entry_set_text(GTK_ENTRY(widget), homepage);
		webkit_web_view_open (WEBKIT_WEB_VIEW (web_view), homepage); //"http://www.google.com/");
	}
	return FALSE;
}
	
	
int
main (int argc, char *argv[])
{
	GtkWidget *widget;

	gtk_set_locale ();
	gtk_init (&argc, &argv);
	
	add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE "/pixmaps");



	window1 = create_window1 ();
	gtk_window_set_default_size (GTK_WINDOW (window1), 800, 600);
	gtk_widget_show (window1);
	gtk_window_set_icon_from_file(GTK_WINDOW(window1), PACKAGE_PIXMAPS_DIR "/woosh.png" ,NULL);
	web_view_hadjustment = gtk_scrolled_window_get_hadjustment(GTK_SCROLLED_WINDOW(lookup_widget(window1, "scrolledwindow1")));
	web_view_vadjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(lookup_widget(window1, "scrolledwindow1")));

	
	g_idle_add_full(G_PRIORITY_LOW, (GSourceFunc)create_web_view,NULL, NULL);
	
	widget = lookup_widget(window1, "hbox2");
	gtk_widget_hide(widget);
	
	g_signal_connect(window1, "delete_event", gtk_main_quit, NULL); /* dirty */


	gtk_main ();
	return 0;
}
